searchData={"content_type":"text/markdown","items":[{"doc":"The command-line option parser","ref":"HelpfulOptions.html","title":"HelpfulOptions","type":"module"},{"doc":"iex> HelpfulOptions.help(switches: [foo: %{type: :string}])\n    {\n      :ok,\n      \"-h, --help                     Show a help message\\n\"  \n      \"-q, --quiet                    Suppress output\\n\"  \n      \"-v, --verbose                  Increase verbosity\\n\"  \n      \"  --foo=FOO                    Optional parameter\"\n    }","ref":"HelpfulOptions.html#help/1","title":"HelpfulOptions.help/1","type":"function"},{"doc":"iex> HelpfulOptions.help!(switches: [foo: %{type: :string}])\n    \"-h, --help                     Show a help message\\n\"  \n    \"-q, --quiet                    Suppress output\\n\"  \n    \"-v, --verbose                  Increase verbosity\\n\"  \n    \"  --foo=FOO                    Optional parameter\"","ref":"HelpfulOptions.html#help!/1","title":"HelpfulOptions.help!/1","type":"function"},{"doc":"Parses command-line arguments, returns an error if\nrequired arguments are not supplied and sets the logging level\n\nArguments are assumed to come in 1 or 2 groups:\n\n* switches like `--format json`,\n* other text.\n\nIn the options, you can specify which switches and other text are acceptable.","ref":"HelpfulOptions.html#parse/2","title":"HelpfulOptions.parse/2","type":"function"},{"doc":"Switches are specified as a list of atoms and maps:\n\nThe `:type` key is required.\n\nThere are to unary types:\n\n* `:boolean` - a switch that is either present or absent\n* `:count` - a switch that can be repeated, the value is the number of times it was repeated.\n\nExample:\n\n    iex> [\"--ok\", \"--plus\", \"--plus\"]\n    iex> |> HelpfulOptions.parse(switches: [ok: %{type: :boolean}, plus: %{type: :count}])\n    {:ok, %{ok: true, plus: 2}, []}\n\nBoolean switches can be negated with `--no-`:\n\n    iex> [\"--no-ok\"]\n    iex> |> HelpfulOptions.parse(switches: [ok: %{type: :boolean}])\n    {:ok, %{ok: false}, []}\n\nThere are three types which specify their argument type:\n\n* `:float` - a switch that takes a floating-point value,\n* `:integer` - a switch that takes an integer value,\n* `:string` - a switch that takes a string value.\n\nExample:\n\n    iex> [\"--height\", \"2.54\", \"--minute\", \"59\", \"--foo\", \"hi\"]\n    iex> |> HelpfulOptions.parse(switches: [\n    iex>   height: %{type: :float},\n    iex>   minute: %{type: :integer},\n    iex>   foo: %{type: :string}\n    iex> ])\n    {:ok, %{height: 2.54, minute: 59, foo: \"hi\"}, []}\n\nThere are 3 'collection' types, which take multiple values:\n\n* `:strings` - the value is a list of strings,\n* `:integers` - the value is a list of integers,\n* `:floats` - the value is a list of floats.\n\nExample:\n\n    iex> args = [\n    iex>   \"--word\", \"hi\", \"--word\", \"there\",\n    iex>   \"--number\", \"42\", \"--number\", \"99\",\n    iex>   \"--height\", \"1.1\", \"--height\", \"2.2\"\n    iex> ]\n    iex> HelpfulOptions.parse(args, switches: [\n    iex>   word: %{type: :strings},\n    iex>   number: %{type: :integers},\n    iex>   height: %{type: :floats}\n    iex> ])\n    {:ok, %{word: [\"hi\", \"there\"], number: [42, 99], height: [1.1, 2.2]}, []}\n\nSwitches that have not been specified are returned as an error:\n\n    iex> HelpfulOptions.parse([\"--bar\", \"hi\"], switches: [foo: %{type: :string}])\n    {:error, %HelpfulOptions.Errors{switches: %HelpfulOptions.SwitchErrors{unknown: [\"--bar\"]}}}\n\nSwitch parameters of the wrong type are returned as an error:\n\n    iex> HelpfulOptions.parse([\"--bar\", \"hi\"], switches: [bar: %{type: :float}])\n    {:error, %HelpfulOptions.Errors{switches: %HelpfulOptions.SwitchErrors{incorrect: [{\"--bar\", \"hi\"}]}}}\n\nIf you want to accept any supplied switches, use `:any`:\n\n    iex> HelpfulOptions.parse([\"--param\", \"value\"], switches: :any)\n    {:ok, %{param: \"value\"}, []}\n\n  Note: using `:any` will not work for switches that do not exist as atoms.\n  [HelpfulOptions will not create new atoms for you](https://hexdocs.pm/elixir/OptionParser.html#parse/2-parsing-unknown-switches).\n\n  You can specify a shortened name for a switch:\n\n    iex> HelpfulOptions.parse([\"-f\", \"hi\"], switches: [foo: %{type: :string, short: :f}])\n    {:ok, %{foo: \"hi\"}, []}\n\n  Aliases can be strings or atoms:\n\n    iex> [\"--foo\", \"hi\"]\n    iex> |> HelpfulOptions.parse(switches: [foo: %{type: :string, short: \"f\"}])\n    {:ok, %{foo: \"hi\"}, []}\n\nSwitches can have default values:\n\n    iex> HelpfulOptions.parse([], switches: [bar: %{type: :string, default: \"Hello\"}])\n    {:ok, %{bar: \"Hello\"}, []}","ref":"HelpfulOptions.html#parse/2-switches","title":"Switches - HelpfulOptions.parse/2","type":"function"},{"doc":"`--help`, `--quiet` and `--verbose` are handled automatically.\n\n  `--help` can be supplied without any configuration:\n\n    iex> HelpfulOptions.parse([\"--help\"], [])\n    {:ok, %{help: true}, []}\n\n  `--quiet` and `--verbose` set the Logger level.\n  By default, it is set to `:info`, `--verbose` sets it to `:debug`,\n  while `:quiet` sets it to `:none`.\n\n    iex> HelpfulOptions.parse([\"--quiet\"], [])\n    {:ok, %{quiet: true}, []}","ref":"HelpfulOptions.html#parse/2-default-switches","title":"Default switches - HelpfulOptions.parse/2","type":"function"},{"doc":"The second group of command-line arguments is other text.\n\n  You can specify how many other parameters are required:\n\n    iex> HelpfulOptions.parse([\"--\", \"first\", \"second\"], other: 2)\n    {:ok, %{}, [\"first\", \"second\"]}\n\n  Note: to distinguish them from subcomands,\n  other parameters must be preceded by `--`, or by switches.\n\n  You can indicate limits with `:min` and/or `:max`:\n\n    iex> HelpfulOptions.parse([\"--\", \"first\", \"second\"], other: %{min: 2, max: 3})\n    {:ok, %{}, [\"first\", \"second\"]}\n\n  Alternatively, you can accept any number of other parameters with `:any`:\n\n    iex> HelpfulOptions.parse([\"--\", \"first\", \"second\"], other: :any)\n    {:ok, %{}, [\"first\", \"second\"]}\n\n  It's an error if you specify a count and the wrong number of other parameters is supplied:\n\n    iex> HelpfulOptions.parse([\"--\", \"first\"], other: 2)\n    {:error, %HelpfulOptions.Errors{other: %HelpfulOptions.OtherErrors{required: 2, actual: 1}}}\n\n  It's also an error if other parameters are supplied when none were specified:\n\n    iex> HelpfulOptions.parse([\"--\", \"pizza\"], [])\n    {:error, %HelpfulOptions.Errors{other: %HelpfulOptions.OtherErrors{unexpected: [\"pizza\"]}}}\n\n  Or, if they are outside the indicated range:\n\n    iex> HelpfulOptions.parse([\"--\", \"first\"], other: %{min: 2, max: 3})\n    {:error, %HelpfulOptions.Errors{other: %HelpfulOptions.OtherErrors{max: 3, min: 2, actual: 1}}}\n\n  Switches and other parameters can, of course, be combined:\n\n    iex> [\"--foo\", \"hi\", \"bar\"]\n    iex> |> HelpfulOptions.parse(switches: [foo: %{type: :string}], other: 1)\n    {:ok, %{foo: \"hi\"}, [\"bar\"]}","ref":"HelpfulOptions.html#parse/2-other","title":"Other - HelpfulOptions.parse/2","type":"function"},{"doc":"iex> HelpfulOptions.parse!([\"--foo\", \"hi\"], switches: [foo: %{type: :string}])\n    {%{foo: \"hi\"}, []}\n\n    iex> HelpfulOptions.parse!([\"--bar\", \"hi\"], switches: [foo: %{type: :string}])\n    ** (ArgumentError) --bar - unknown switch","ref":"HelpfulOptions.html#parse!/2","title":"HelpfulOptions.parse!/2","type":"function"},{"doc":"","ref":"HelpfulOptions.html#t:argv/0","title":"HelpfulOptions.argv/0","type":"type"},{"doc":"","ref":"HelpfulOptions.html#t:options/0","title":"HelpfulOptions.options/0","type":"type"},{"doc":"Represents an error that occurred while parsing options.","ref":"HelpfulOptions.Errors.html","title":"HelpfulOptions.Errors","type":"module"},{"doc":"","ref":"HelpfulOptions.Errors.html#t:t/0","title":"HelpfulOptions.Errors.t/0","type":"type"},{"doc":"","ref":"HelpfulOptions.Logging.html","title":"HelpfulOptions.Logging","type":"module"},{"doc":"","ref":"HelpfulOptions.Logging.html#apply/1","title":"HelpfulOptions.Logging.apply/1","type":"function"},{"doc":"","ref":"HelpfulOptions.Other.html","title":"HelpfulOptions.Other","type":"module"},{"doc":"You can specify how many other parameters are required:\n\n    iex> HelpfulOptions.Other.check([\"first\", \"second\"], 2)\n    {:ok}\n\nYou can indicate limits with `:min` and/or `:max`:\n\n    iex> HelpfulOptions.Other.check([\"first\", \"second\"], %{min: 2, max: 3})\n    {:ok}\n\nAlternatively, you can accept any number of other parameters with `:any`:\n\n    iex> HelpfulOptions.Other.check([\"first\", \"second\"], :any)\n    {:ok}\n\nIt's an error if you specify a count and the wrong number of other parameters is supplied:\n\n    iex> HelpfulOptions.Other.check([\"first\"], 2)\n    {:error, %HelpfulOptions.OtherErrors{required: 2, actual: 1}}\n\nIt's also an error if other parameters are supplied when none were specified:\n\n    iex> HelpfulOptions.Other.check([\"pizza\"], nil)\n    {:error, %HelpfulOptions.OtherErrors{unexpected: [\"pizza\"]}}\n\nOr, if they are outside the indicated range:\n\n    iex> HelpfulOptions.Other.check([\"first\"], %{min: 2, max: 3})\n    {:error, %HelpfulOptions.OtherErrors{max: 3, min: 2, actual: 1}}","ref":"HelpfulOptions.Other.html#check/2","title":"HelpfulOptions.Other.check/2","type":"function"},{"doc":"","ref":"HelpfulOptions.Other.html#t:other_options/0","title":"HelpfulOptions.Other.other_options/0","type":"type"},{"doc":"","ref":"HelpfulOptions.Other.html#t:t/0","title":"HelpfulOptions.Other.t/0","type":"type"},{"doc":"","ref":"HelpfulOptions.OtherErrors.html","title":"HelpfulOptions.OtherErrors","type":"module"},{"doc":"","ref":"HelpfulOptions.OtherErrors.html#t:t/0","title":"HelpfulOptions.OtherErrors.t/0","type":"type"},{"doc":"","ref":"HelpfulOptions.Subcommands.html","title":"HelpfulOptions.Subcommands","type":"module"},{"doc":"iex> HelpfulOptions.Subcommands.strip([\"foo\", \"bar\", \"--baz\", \"qux\"])\n    {:ok, [\"foo\", \"bar\"], [\"--baz\", \"qux\"]}","ref":"HelpfulOptions.Subcommands.html#strip/1","title":"HelpfulOptions.Subcommands.strip/1","type":"function"},{"doc":"","ref":"HelpfulOptions.SwitchErrors.html","title":"HelpfulOptions.SwitchErrors","type":"module"},{"doc":"","ref":"HelpfulOptions.SwitchErrors.html#t:incorrect/0","title":"HelpfulOptions.SwitchErrors.incorrect/0","type":"type"},{"doc":"","ref":"HelpfulOptions.SwitchErrors.html#t:invalid/0","title":"HelpfulOptions.SwitchErrors.invalid/0","type":"type"},{"doc":"","ref":"HelpfulOptions.SwitchErrors.html#t:missing/0","title":"HelpfulOptions.SwitchErrors.missing/0","type":"type"},{"doc":"","ref":"HelpfulOptions.SwitchErrors.html#t:t/0","title":"HelpfulOptions.SwitchErrors.t/0","type":"type"},{"doc":"","ref":"HelpfulOptions.Switches.html","title":"HelpfulOptions.Switches","type":"module"},{"doc":"Returns the help block related to switches\n\n    iex> HelpfulOptions.Switches.help(foo: %{type: :string}, bar: %{type: :integer})\n    {\n      :ok,\n      \"-h, --help                     Show a help message\\n\"  \n      \"-q, --quiet                    Suppress output\\n\"  \n      \"-v, --verbose                  Increase verbosity\\n\"  \n      \"  --foo=FOO                    Optional parameter\\n\"  \n      \"  --bar=BAR                    Optional parameter\"\n    }\n\nReturns a generic test when `:any` is used:\n\n    iex> HelpfulOptions.Switches.help(:any)\n    {:ok, \"Accepts any switch-type arguments\"}\n\nBy default, it returns an empty string:\n\n    iex> HelpfulOptions.Switches.help(nil)\n    {\n      :ok,\n      \"-h, --help                     Show a help message\\n\"  \n      \"-q, --quiet                    Suppress output\\n\"  \n      \"-v, --verbose                  Increase verbosity\"\n    }","ref":"HelpfulOptions.Switches.html#help/1","title":"HelpfulOptions.Switches.help/1","type":"function"},{"doc":"Switches that have not been specified are returned as an error:\n\n    iex> HelpfulOptions.Switches.parse([\"--bar\", \"hi\"], foo: %{type: :string})\n    {:error, %HelpfulOptions.SwitchErrors{unknown: [\"--bar\"]}}\n\nSwitch parameters of the wrong type are returned as an error:\n\n    iex> HelpfulOptions.Switches.parse([\"--bar\", \"hi\"], bar: %{type: :float})\n    {:error, %HelpfulOptions.SwitchErrors{incorrect: [{\"--bar\", \"hi\"}]}}\n\nInvalid switch types are returned as an error:\n\n    iex> HelpfulOptions.Switches.parse([\"--bar\", \"hi\"], bar: %{type: :invalid})\n    {:error, %HelpfulOptions.SwitchErrors{invalid: [bar: {:invalid_type, :invalid}]}}\n\n`:default` and `:required` are incompatible\n\n    iex> HelpfulOptions.Switches.parse([], [foo: %{type: :string, required: true, default: \"ok\"}])\n    {:error, %HelpfulOptions.SwitchErrors{invalid: [foo: :required_and_default]}}","ref":"HelpfulOptions.Switches.html#parse/2","title":"HelpfulOptions.Switches.parse/2","type":"function"},{"doc":"`--help`, `--quiet` and `--verbose` are handled automatically.\n\n  `--help` can be supplied without any configuration:\n\n    iex> HelpfulOptions.Switches.parse([\"--help\"], nil)\n    {:ok, %{help: true}, []}\n\n  `--quiet` and `--verbose` have the side-effect of setting the Logger level.\n  By default, it is set to `:info`, `--verbose` sets it to `:debug`,\n  while `:quiet` sets it to `:none`.\n\n    iex> HelpfulOptions.Switches.parse([\"--quiet\"], nil)\n    {:ok, %{quiet: true}, []}","ref":"HelpfulOptions.Switches.html#parse/2-default-switches","title":"Default switches - HelpfulOptions.Switches.parse/2","type":"function"},{"doc":"","ref":"HelpfulOptions.Switches.html#t:switch/0","title":"HelpfulOptions.Switches.switch/0","type":"type"},{"doc":"","ref":"HelpfulOptions.Switches.html#t:switch_type/0","title":"HelpfulOptions.Switches.switch_type/0","type":"type"},{"doc":"","ref":"HelpfulOptions.Switches.html#t:t/0","title":"HelpfulOptions.Switches.t/0","type":"type"}]}